==> datadog-api-client-1.10.0.tar.gz: datadog-api-client-1.10.0/src/datadog_api_client/v1/model/host_map_widget_definition_requests.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.host_map_request import HostMapRequest
    from datadog_api_client.v1.model.host_map_request import HostMapRequest

    globals()["HostMapRequest"] = HostMapRequest
    globals()["HostMapRequest"] = HostMapRequest


class HostMapWidgetDefinitionRequests(ModelNormal):

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "fill": (HostMapRequest,),
            "size": (HostMapRequest,),
        }

    attribute_map = {
        "fill": "fill",
        "size": "size",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """
        List of definitions.

        :param fill: Updated host map.
        :type fill: HostMapRequest, optional

        :param size: Updated host map.
        :type size: HostMapRequest, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(HostMapWidgetDefinitionRequests, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self

==> datadog-api-client-1.11.0.tar.gz: datadog-api-client-1.11.0/src/datadog_api_client/v1/model/host_map_widget_definition_requests.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.host_map_request import HostMapRequest
    from datadog_api_client.v1.model.host_map_request import HostMapRequest

    globals()["HostMapRequest"] = HostMapRequest
    globals()["HostMapRequest"] = HostMapRequest


class HostMapWidgetDefinitionRequests(ModelNormal):
    @cached_property
    def openapi_types(_):
        lazy_import()
        return {
            "fill": (HostMapRequest,),
            "size": (HostMapRequest,),
        }

    attribute_map = {
        "fill": "fill",
        "size": "size",
    }

    def __init__(self, *args, **kwargs):
        """
        List of definitions.

        :param fill: Updated host map.
        :type fill: HostMapRequest, optional

        :param size: Updated host map.
        :type size: HostMapRequest, optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(HostMapWidgetDefinitionRequests, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
